@@ -24,7 +24,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: enable_pps.c,v 1.7.2.1 1999/03/14 01:38:23 windl Exp $
+ * $Id: enable_pps.c,v 1.7.2.2 1999/03/27 22:25:33 windl Exp $
  */
 #include	<unistd.h>
 #include	<time.h>
@@ -32,6 +32,7 @@
 #include	<stdio.h>
 #include	<string.h>
 #include	<errno.h>
+#include	<sys/utsname.h>
 
 #include	<linux/version.h>
 #define	NANO	/* prefer the Nanokernel if available */
@@ -77,7 +78,7 @@
 #define	BITS_OFF(v, b)			((v) & ~(b))
 #define	BITS_ON(v, b)			((v) | (b))
 
-static	const char	id[] = "$Id: enable_pps.c,v 1.7.2.1 1999/03/14 01:38:23 windl Exp $";
+static	const char	id[] = "$Id: enable_pps.c,v 1.7.2.2 1999/03/27 22:25:33 windl Exp $";
 
 #define	BIT(n)	(1UL << (n))
 #define OPT_MONITOR		BIT(0)	/* perform monitor loop */
@@ -447,20 +448,38 @@ static	void	calibrate(struct timex *txp, struct ppsclockev *evp)
 /* monitor PPS jitter */
 static	void	monitor_jitter(struct timex *txp, struct ppsclockev *evp)
 {
-	struct timeval	last;
+	struct timeval	now, last;
 	long		delta, last_delta;
+	int		last_serial;
+	struct timespec	sleeper;
 
-	last_delta = last.tv_sec = last.tv_usec = 0;
+	last_delta = last.tv_sec = last.tv_usec = last_serial = 0;
 	txp->modes = 0;
+	sleeper.tv_sec = 0;
+	sleeper.tv_nsec = 500000000;
 	while ( 1 )
 	{
 		pps_status("monitor_jitter(): ", 0, 0, txp->status, evp);
-		delta =  evp->tv.tv_usec - last.tv_usec;
-		delta += (evp->tv.tv_sec - last.tv_sec) * 1000000L;
-		last = evp->tv;
-		printf("%6d %8ld\n", evp->serial, delta - last_delta);
+		if ( evp->serial == last_serial )
+		{
+			nanosleep(&sleeper, &sleeper);
+			continue;
+		}
+		last_serial = evp->serial;
+		now = evp->tv;
+		delta =  now.tv_usec - last.tv_usec;
+		delta += (now.tv_sec - last.tv_sec) * 1000000L;
+		printf("%6d %8ld", evp->serial, delta - last_delta);
+		if ( delta - last_delta > 1000 || delta - last_delta < -1000 )
+		{
+			printf("\t%d:%ld %d:%ld",
+			       last.tv_sec, last.tv_usec,
+			       now.tv_sec, now.tv_usec);
+		}
+		printf("\n");
+		fflush(stdout);
+		last = now;
 		last_delta = delta;
-		sleep(1);
 	}
 }
 
@@ -482,6 +501,7 @@ static	void	usage(void)
 /* input has to be redirected to the desired device! */
 int	main(int argc, char *argv[])
 {
+	struct utsname	un;
 	int		stat = TIOCM_RTS;	/* RTS MODEM control line */
 	struct serial_struct ss;
 	struct timex 	tx;
@@ -490,11 +510,13 @@ int	main(int argc, char *argv[])
 
 	fprintf(stderr,
 		"WARNING: This program may invalidate your system time!\n");
-	printf("(This version has been compiled with"
+	printf("(This version has been compiled in Linux %s with"
 #ifndef	STA_NANO
 	       "out"
 #endif
-	       " nanokernel support in Linux %s)\n", UTS_RELEASE);
+	       " nanokernel support.\n", UTS_RELEASE);
+	uname(&un);
+	printf(" Now running %s %s)\n", un.sysname, un.release);
 	while ( (ch = getopt(argc, argv, "CejkOp:S")) != -1 )
 	{
 		switch ( ch )
